@@ -1,5 +1,3 @@
-from typing import Union
-
 class ScraperError(Exception):
 	def __init__(self, *args, **kwargs):
 		args = list(args)
@@ -34,7 +32,7 @@ class YotubeLiveError(ScraperError):
 class YotubeAgeRestrictedError(ScraperError):
 	pass
 
-class IGRateLimitAccured(ScraperError):
+class IGRateLimitOccurred(ScraperError):
 	pass
 
 class CaptchaIssue(ScraperError):
